@@ -1070,6 +1070,7 @@ class Confirms(object):
     SCREEN_PROCEED = 'SCREEN_PROCEED'
     SETTINGS = 'SETTINGS_PROCEED'
     UPGRADE_DISK_RESIZE_PROCEED = 'UPGRADE_DISK_RESIZE_PROCEED'
+    LM_VOLUMES_UPGRADE_PROCEED = 'LM_VOLUME_UPGRADE_PROCEED'
 
 
 @util.export
@@ -1092,6 +1093,8 @@ class Upgrade(object):
     BACKUP_VOL_UUID = 'OVEHOSTED_UPGRADE/backupVolUUID'
     BACKUP_SIZE_GB = 'OVEHOSTED_UPGRADE/backupImgSizeGB'
     EXTEND_VOLUME = 'OVEHOSTED_UPGRADE/extend_volume'
+    UPGRADE_CREATE_LM_VOLUMES = 'OVEHOSTED_UPGRADE/createLMVolumes'
+    LM_VOLUMES_UPGRADE_PROCEED = 'OVEHOSTED_UPGRADE/LMVolumesUpgradeProceed'
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
